@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpTSymLinearSolver.cpp 2276 2013-05-05 12:33:44Z stefan $
+// $Id: IpTSymLinearSolver.cpp 2476 2014-04-08 09:41:07Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-03-17
 
@@ -21,6 +21,7 @@ namespace Ipopt
    SmartPtr<TSymScalingMethod> scaling_method)
       :
       SymLinearSolver(),
+      atag_(0),
       dim_(0),
       nonzeros_triplet_(0),
       nonzeros_compressed_(0),
@@ -90,7 +91,7 @@ namespace Ipopt
 
     if (!warm_start_same_structure_) {
       // Reset all private data
-      atag_=TaggedObject::Tag();
+      atag_=0;
       dim_=0;
       nonzeros_triplet_=0;
       nonzeros_compressed_=0;
@@ -174,7 +175,7 @@ namespace Ipopt
     DBG_ASSERT(nonzeros_triplet_== TripletHelper::GetNumberEntries(sym_A));
 
     // Check if the matrix has been changed
-    DBG_PRINT((1,"atag_=%d sym_A->GetTag()=%d\n",atag_,sym_A.GetTag()));
+    DBG_PRINT((1, "atag_ = (%p,%d)   sym_A->GetTag() = (%p,%d)\n", atag_.first, atag_.second, sym_A.GetTag().first, sym_A.GetTag().second));
     bool new_matrix = sym_A.HasChanged(atag_);
     atag_ = sym_A.GetTag();
 
